import java.io.*;

interface Compute {
    public Object compute(Object o);
}

interface MyIterator {
    public boolean hasMoreElements();
    public Object nextElement();
}

class InReader implements MyIterator {
    BufferedReader br;
    String line;
    public InReader(InputStream is) throws IOException {
        br = new BufferedReader(new InputStreamReader(is));
        line = null;
    }
    public boolean hasMoreElements(){
        if(line == null){
            try {
                line = br.readLine();
            } catch(IOException e){}
        }
        return line != null;
    }
    public Object nextElement() {
        String r = line;
        line = null;
        if(r != null)
            return r;
        try {
            line = br.readLine();
        } catch(IOException e){}
        return line;
    }
}

class Capitalizer implements Compute {
    public Object compute(Object o){
        String s = (String)o;
        return s.toUpperCase();
    }
}

public class LineTest {

    public static MyIterator map(final Compute f,final MyIterator i){
        return new MyIterator(){
            public boolean hasMoreElements(){
                return i.hasMoreElements();
            }
            public Object nextElement(){
                return f.compute(i.nextElement());
            }
        };
    }

    public static void main(String[] args) throws Throwable {
        
        MyIterator p = 
            map(
                new Compute(){
                    public Object compute(Object o){
                        String s = (String)o;
                        return s.trim();
                    }
                }, 
                map(new Capitalizer(),
                    new InReader(System.in)
                )
            );
        // add line number prefix.
        MyIterator r = map(   
            new Compute(){
                int line =0;
                public Object compute(Object o){
                    String s = (String)o;
                    return "["+(line++)+"]:"+s;
                }
            }
        ,p);

        while(r.hasMoreElements()){
            String line = (String)r.nextElement();
            System.out.println("You've typed: "+line);
        }
    }
}


